"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ClusterApplication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AdditionalInfoEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ADDITIONAL_INFO_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def additional_info(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def args(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    name: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        additional_info: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        args: collections.abc.Iterable[builtins.str] | None = ...,
        name: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional_info", b"additional_info", "args", b"args", "name", b"name", "resource_info", b"resource_info", "version", b"version"]) -> None: ...

global___ClusterApplication = ClusterApplication

@typing_extensions.final
class ClusterScriptBootstrapActionConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def args(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    path: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        args: collections.abc.Iterable[builtins.str] | None = ...,
        path: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["args", b"args", "path", b"path", "resource_info", b"resource_info"]) -> None: ...

global___ClusterScriptBootstrapActionConfig = ClusterScriptBootstrapActionConfig

@typing_extensions.final
class ClusterBootstrapActionConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SCRIPT_BOOTSTRAP_ACTION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def script_bootstrap_action(self) -> global___ClusterScriptBootstrapActionConfig: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        script_bootstrap_action: global___ClusterScriptBootstrapActionConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "script_bootstrap_action", b"script_bootstrap_action"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "script_bootstrap_action", b"script_bootstrap_action"]) -> None: ...

global___ClusterBootstrapActionConfig = ClusterBootstrapActionConfig

@typing_extensions.final
class ClusterConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ConfigurationPropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLASSIFICATION_FIELD_NUMBER: builtins.int
    CONFIGURATION_PROPERTIES_FIELD_NUMBER: builtins.int
    CONFIGURATIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    classification: builtins.str
    @property
    def configuration_properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClusterConfiguration]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        classification: builtins.str = ...,
        configuration_properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        configurations: collections.abc.Iterable[global___ClusterConfiguration] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["classification", b"classification", "configuration_properties", b"configuration_properties", "configurations", b"configurations", "resource_info", b"resource_info"]) -> None: ...

global___ClusterConfiguration = ClusterConfiguration

@typing_extensions.final
class ClusterVolumeSpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IOPS_FIELD_NUMBER: builtins.int
    SIZE_IN_GB_FIELD_NUMBER: builtins.int
    VOLUME_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    iops: builtins.int
    size_in_gb: builtins.int
    volume_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        iops: builtins.int = ...,
        size_in_gb: builtins.int = ...,
        volume_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["iops", b"iops", "resource_info", b"resource_info", "size_in_gb", b"size_in_gb", "volume_type", b"volume_type"]) -> None: ...

global___ClusterVolumeSpecification = ClusterVolumeSpecification

@typing_extensions.final
class ClusterEbsBlockDeviceConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VOLUME_SPECIFICATION_FIELD_NUMBER: builtins.int
    VOLUMES_PER_INSTANCE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def volume_specification(self) -> global___ClusterVolumeSpecification: ...
    volumes_per_instance: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        volume_specification: global___ClusterVolumeSpecification | None = ...,
        volumes_per_instance: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "volume_specification", b"volume_specification"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "volume_specification", b"volume_specification", "volumes_per_instance", b"volumes_per_instance"]) -> None: ...

global___ClusterEbsBlockDeviceConfig = ClusterEbsBlockDeviceConfig

@typing_extensions.final
class ClusterEbsConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EBS_BLOCK_DEVICE_CONFIGS_FIELD_NUMBER: builtins.int
    EBS_OPTIMIZED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def ebs_block_device_configs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClusterEbsBlockDeviceConfig]: ...
    ebs_optimized: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        ebs_block_device_configs: collections.abc.Iterable[global___ClusterEbsBlockDeviceConfig] | None = ...,
        ebs_optimized: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ebs_block_device_configs", b"ebs_block_device_configs", "ebs_optimized", b"ebs_optimized", "resource_info", b"resource_info"]) -> None: ...

global___ClusterEbsConfiguration = ClusterEbsConfiguration

@typing_extensions.final
class ClusterInstanceTypeConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BID_PRICE_FIELD_NUMBER: builtins.int
    BID_PRICE_AS_PERCENTAGE_OF_ON_DEMAND_PRICE_FIELD_NUMBER: builtins.int
    CONFIGURATIONS_FIELD_NUMBER: builtins.int
    EBS_CONFIGURATION_FIELD_NUMBER: builtins.int
    INSTANCE_TYPE_FIELD_NUMBER: builtins.int
    WEIGHTED_CAPACITY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    bid_price: builtins.str
    bid_price_as_percentage_of_on_demand_price: builtins.float
    @property
    def configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClusterConfiguration]: ...
    @property
    def ebs_configuration(self) -> global___ClusterEbsConfiguration: ...
    instance_type: builtins.str
    weighted_capacity: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        bid_price: builtins.str = ...,
        bid_price_as_percentage_of_on_demand_price: builtins.float = ...,
        configurations: collections.abc.Iterable[global___ClusterConfiguration] | None = ...,
        ebs_configuration: global___ClusterEbsConfiguration | None = ...,
        instance_type: builtins.str = ...,
        weighted_capacity: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ebs_configuration", b"ebs_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bid_price", b"bid_price", "bid_price_as_percentage_of_on_demand_price", b"bid_price_as_percentage_of_on_demand_price", "configurations", b"configurations", "ebs_configuration", b"ebs_configuration", "instance_type", b"instance_type", "resource_info", b"resource_info", "weighted_capacity", b"weighted_capacity"]) -> None: ...

global___ClusterInstanceTypeConfig = ClusterInstanceTypeConfig

@typing_extensions.final
class ClusterSpotProvisioningSpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BLOCK_DURATION_MINUTES_FIELD_NUMBER: builtins.int
    TIMEOUT_ACTION_FIELD_NUMBER: builtins.int
    TIMEOUT_DURATION_MINUTES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    block_duration_minutes: builtins.int
    timeout_action: builtins.str
    timeout_duration_minutes: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        block_duration_minutes: builtins.int = ...,
        timeout_action: builtins.str = ...,
        timeout_duration_minutes: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["block_duration_minutes", b"block_duration_minutes", "resource_info", b"resource_info", "timeout_action", b"timeout_action", "timeout_duration_minutes", b"timeout_duration_minutes"]) -> None: ...

global___ClusterSpotProvisioningSpecification = ClusterSpotProvisioningSpecification

@typing_extensions.final
class ClusterInstanceFleetProvisioningSpecifications(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SPOT_SPECIFICATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def spot_specification(self) -> global___ClusterSpotProvisioningSpecification: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        spot_specification: global___ClusterSpotProvisioningSpecification | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "spot_specification", b"spot_specification"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "spot_specification", b"spot_specification"]) -> None: ...

global___ClusterInstanceFleetProvisioningSpecifications = ClusterInstanceFleetProvisioningSpecifications

@typing_extensions.final
class ClusterInstanceFleetConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INSTANCE_TYPE_CONFIGS_FIELD_NUMBER: builtins.int
    LAUNCH_SPECIFICATIONS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TARGET_ON_DEMAND_CAPACITY_FIELD_NUMBER: builtins.int
    TARGET_SPOT_CAPACITY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def instance_type_configs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClusterInstanceTypeConfig]: ...
    @property
    def launch_specifications(self) -> global___ClusterInstanceFleetProvisioningSpecifications: ...
    name: builtins.str
    target_on_demand_capacity: builtins.int
    target_spot_capacity: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        instance_type_configs: collections.abc.Iterable[global___ClusterInstanceTypeConfig] | None = ...,
        launch_specifications: global___ClusterInstanceFleetProvisioningSpecifications | None = ...,
        name: builtins.str = ...,
        target_on_demand_capacity: builtins.int = ...,
        target_spot_capacity: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["launch_specifications", b"launch_specifications", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["instance_type_configs", b"instance_type_configs", "launch_specifications", b"launch_specifications", "name", b"name", "resource_info", b"resource_info", "target_on_demand_capacity", b"target_on_demand_capacity", "target_spot_capacity", b"target_spot_capacity"]) -> None: ...

global___ClusterInstanceFleetConfig = ClusterInstanceFleetConfig

@typing_extensions.final
class ClusterScalingConstraints(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MAX_CAPACITY_FIELD_NUMBER: builtins.int
    MIN_CAPACITY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    max_capacity: builtins.int
    min_capacity: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        max_capacity: builtins.int = ...,
        min_capacity: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_capacity", b"max_capacity", "min_capacity", b"min_capacity", "resource_info", b"resource_info"]) -> None: ...

global___ClusterScalingConstraints = ClusterScalingConstraints

@typing_extensions.final
class ClusterSimpleScalingPolicyConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ADJUSTMENT_TYPE_FIELD_NUMBER: builtins.int
    COOL_DOWN_FIELD_NUMBER: builtins.int
    SCALING_ADJUSTMENT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    adjustment_type: builtins.str
    cool_down: builtins.int
    scaling_adjustment: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        adjustment_type: builtins.str = ...,
        cool_down: builtins.int = ...,
        scaling_adjustment: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["adjustment_type", b"adjustment_type", "cool_down", b"cool_down", "resource_info", b"resource_info", "scaling_adjustment", b"scaling_adjustment"]) -> None: ...

global___ClusterSimpleScalingPolicyConfiguration = ClusterSimpleScalingPolicyConfiguration

@typing_extensions.final
class ClusterScalingAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MARKET_FIELD_NUMBER: builtins.int
    SIMPLE_SCALING_POLICY_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    market: builtins.str
    @property
    def simple_scaling_policy_configuration(self) -> global___ClusterSimpleScalingPolicyConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        market: builtins.str = ...,
        simple_scaling_policy_configuration: global___ClusterSimpleScalingPolicyConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "simple_scaling_policy_configuration", b"simple_scaling_policy_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["market", b"market", "resource_info", b"resource_info", "simple_scaling_policy_configuration", b"simple_scaling_policy_configuration"]) -> None: ...

global___ClusterScalingAction = ClusterScalingAction

@typing_extensions.final
class ClusterMetricDimension(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___ClusterMetricDimension = ClusterMetricDimension

@typing_extensions.final
class ClusterCloudWatchAlarmDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COMPARISON_OPERATOR_FIELD_NUMBER: builtins.int
    DIMENSIONS_FIELD_NUMBER: builtins.int
    EVALUATION_PERIODS_FIELD_NUMBER: builtins.int
    METRIC_NAME_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    PERIOD_FIELD_NUMBER: builtins.int
    STATISTIC_FIELD_NUMBER: builtins.int
    THRESHOLD_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    comparison_operator: builtins.str
    @property
    def dimensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClusterMetricDimension]: ...
    evaluation_periods: builtins.int
    metric_name: builtins.str
    namespace: builtins.str
    period: builtins.int
    statistic: builtins.str
    threshold: builtins.float
    unit: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        comparison_operator: builtins.str = ...,
        dimensions: collections.abc.Iterable[global___ClusterMetricDimension] | None = ...,
        evaluation_periods: builtins.int = ...,
        metric_name: builtins.str = ...,
        namespace: builtins.str = ...,
        period: builtins.int = ...,
        statistic: builtins.str = ...,
        threshold: builtins.float = ...,
        unit: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["comparison_operator", b"comparison_operator", "dimensions", b"dimensions", "evaluation_periods", b"evaluation_periods", "metric_name", b"metric_name", "namespace", b"namespace", "period", b"period", "resource_info", b"resource_info", "statistic", b"statistic", "threshold", b"threshold", "unit", b"unit"]) -> None: ...

global___ClusterCloudWatchAlarmDefinition = ClusterCloudWatchAlarmDefinition

@typing_extensions.final
class ClusterScalingTrigger(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLOUD_WATCH_ALARM_DEFINITION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def cloud_watch_alarm_definition(self) -> global___ClusterCloudWatchAlarmDefinition: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cloud_watch_alarm_definition: global___ClusterCloudWatchAlarmDefinition | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cloud_watch_alarm_definition", b"cloud_watch_alarm_definition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_watch_alarm_definition", b"cloud_watch_alarm_definition", "resource_info", b"resource_info"]) -> None: ...

global___ClusterScalingTrigger = ClusterScalingTrigger

@typing_extensions.final
class ClusterScalingRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TRIGGER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def action(self) -> global___ClusterScalingAction: ...
    description: builtins.str
    name: builtins.str
    @property
    def trigger(self) -> global___ClusterScalingTrigger: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        action: global___ClusterScalingAction | None = ...,
        description: builtins.str = ...,
        name: builtins.str = ...,
        trigger: global___ClusterScalingTrigger | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["action", b"action", "resource_info", b"resource_info", "trigger", b"trigger"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "description", b"description", "name", b"name", "resource_info", b"resource_info", "trigger", b"trigger"]) -> None: ...

global___ClusterScalingRule = ClusterScalingRule

@typing_extensions.final
class ClusterAutoScalingPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONSTRAINTS_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def constraints(self) -> global___ClusterScalingConstraints: ...
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClusterScalingRule]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        constraints: global___ClusterScalingConstraints | None = ...,
        rules: collections.abc.Iterable[global___ClusterScalingRule] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["constraints", b"constraints", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["constraints", b"constraints", "resource_info", b"resource_info", "rules", b"rules"]) -> None: ...

global___ClusterAutoScalingPolicy = ClusterAutoScalingPolicy

@typing_extensions.final
class ClusterInstanceGroupConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AUTO_SCALING_POLICY_FIELD_NUMBER: builtins.int
    BID_PRICE_FIELD_NUMBER: builtins.int
    CONFIGURATIONS_FIELD_NUMBER: builtins.int
    EBS_CONFIGURATION_FIELD_NUMBER: builtins.int
    INSTANCE_COUNT_FIELD_NUMBER: builtins.int
    INSTANCE_TYPE_FIELD_NUMBER: builtins.int
    MARKET_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def auto_scaling_policy(self) -> global___ClusterAutoScalingPolicy: ...
    bid_price: builtins.str
    @property
    def configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClusterConfiguration]: ...
    @property
    def ebs_configuration(self) -> global___ClusterEbsConfiguration: ...
    instance_count: builtins.int
    instance_type: builtins.str
    market: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        auto_scaling_policy: global___ClusterAutoScalingPolicy | None = ...,
        bid_price: builtins.str = ...,
        configurations: collections.abc.Iterable[global___ClusterConfiguration] | None = ...,
        ebs_configuration: global___ClusterEbsConfiguration | None = ...,
        instance_count: builtins.int = ...,
        instance_type: builtins.str = ...,
        market: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auto_scaling_policy", b"auto_scaling_policy", "ebs_configuration", b"ebs_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_scaling_policy", b"auto_scaling_policy", "bid_price", b"bid_price", "configurations", b"configurations", "ebs_configuration", b"ebs_configuration", "instance_count", b"instance_count", "instance_type", b"instance_type", "market", b"market", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ClusterInstanceGroupConfig = ClusterInstanceGroupConfig

@typing_extensions.final
class ClusterPlacementType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AVAILABILITY_ZONE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    availability_zone: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        availability_zone: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["availability_zone", b"availability_zone", "resource_info", b"resource_info"]) -> None: ...

global___ClusterPlacementType = ClusterPlacementType

@typing_extensions.final
class ClusterJobFlowInstancesConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ADDITIONAL_MASTER_SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    ADDITIONAL_SLAVE_SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    CORE_INSTANCE_FLEET_FIELD_NUMBER: builtins.int
    CORE_INSTANCE_GROUP_FIELD_NUMBER: builtins.int
    EC2_KEY_NAME_FIELD_NUMBER: builtins.int
    EC2_SUBNET_ID_FIELD_NUMBER: builtins.int
    EC2_SUBNET_IDS_FIELD_NUMBER: builtins.int
    EMR_MANAGED_MASTER_SECURITY_GROUP_FIELD_NUMBER: builtins.int
    EMR_MANAGED_SLAVE_SECURITY_GROUP_FIELD_NUMBER: builtins.int
    HADOOP_VERSION_FIELD_NUMBER: builtins.int
    KEEP_JOB_FLOW_ALIVE_WHEN_NO_STEPS_FIELD_NUMBER: builtins.int
    MASTER_INSTANCE_FLEET_FIELD_NUMBER: builtins.int
    MASTER_INSTANCE_GROUP_FIELD_NUMBER: builtins.int
    PLACEMENT_FIELD_NUMBER: builtins.int
    SERVICE_ACCESS_SECURITY_GROUP_FIELD_NUMBER: builtins.int
    TERMINATION_PROTECTED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def additional_master_security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def additional_slave_security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def core_instance_fleet(self) -> global___ClusterInstanceFleetConfig: ...
    @property
    def core_instance_group(self) -> global___ClusterInstanceGroupConfig: ...
    ec2_key_name: builtins.str
    ec2_subnet_id: builtins.str
    @property
    def ec2_subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    emr_managed_master_security_group: builtins.str
    emr_managed_slave_security_group: builtins.str
    hadoop_version: builtins.str
    keep_job_flow_alive_when_no_steps: builtins.bool
    @property
    def master_instance_fleet(self) -> global___ClusterInstanceFleetConfig: ...
    @property
    def master_instance_group(self) -> global___ClusterInstanceGroupConfig: ...
    @property
    def placement(self) -> global___ClusterPlacementType: ...
    service_access_security_group: builtins.str
    termination_protected: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        additional_master_security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        additional_slave_security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        core_instance_fleet: global___ClusterInstanceFleetConfig | None = ...,
        core_instance_group: global___ClusterInstanceGroupConfig | None = ...,
        ec2_key_name: builtins.str = ...,
        ec2_subnet_id: builtins.str = ...,
        ec2_subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
        emr_managed_master_security_group: builtins.str = ...,
        emr_managed_slave_security_group: builtins.str = ...,
        hadoop_version: builtins.str = ...,
        keep_job_flow_alive_when_no_steps: builtins.bool = ...,
        master_instance_fleet: global___ClusterInstanceFleetConfig | None = ...,
        master_instance_group: global___ClusterInstanceGroupConfig | None = ...,
        placement: global___ClusterPlacementType | None = ...,
        service_access_security_group: builtins.str = ...,
        termination_protected: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["core_instance_fleet", b"core_instance_fleet", "core_instance_group", b"core_instance_group", "master_instance_fleet", b"master_instance_fleet", "master_instance_group", b"master_instance_group", "placement", b"placement", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional_master_security_groups", b"additional_master_security_groups", "additional_slave_security_groups", b"additional_slave_security_groups", "core_instance_fleet", b"core_instance_fleet", "core_instance_group", b"core_instance_group", "ec2_key_name", b"ec2_key_name", "ec2_subnet_id", b"ec2_subnet_id", "ec2_subnet_ids", b"ec2_subnet_ids", "emr_managed_master_security_group", b"emr_managed_master_security_group", "emr_managed_slave_security_group", b"emr_managed_slave_security_group", "hadoop_version", b"hadoop_version", "keep_job_flow_alive_when_no_steps", b"keep_job_flow_alive_when_no_steps", "master_instance_fleet", b"master_instance_fleet", "master_instance_group", b"master_instance_group", "placement", b"placement", "resource_info", b"resource_info", "service_access_security_group", b"service_access_security_group", "termination_protected", b"termination_protected"]) -> None: ...

global___ClusterJobFlowInstancesConfig = ClusterJobFlowInstancesConfig

@typing_extensions.final
class ClusterKerberosAttributes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AD_DOMAIN_JOIN_PASSWORD_FIELD_NUMBER: builtins.int
    AD_DOMAIN_JOIN_USER_FIELD_NUMBER: builtins.int
    CROSS_REALM_TRUST_PRINCIPAL_PASSWORD_FIELD_NUMBER: builtins.int
    KDC_ADMIN_PASSWORD_FIELD_NUMBER: builtins.int
    REALM_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    ad_domain_join_password: builtins.str
    ad_domain_join_user: builtins.str
    cross_realm_trust_principal_password: builtins.str
    kdc_admin_password: builtins.str
    realm: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        ad_domain_join_password: builtins.str = ...,
        ad_domain_join_user: builtins.str = ...,
        cross_realm_trust_principal_password: builtins.str = ...,
        kdc_admin_password: builtins.str = ...,
        realm: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_domain_join_password", b"ad_domain_join_password", "ad_domain_join_user", b"ad_domain_join_user", "cross_realm_trust_principal_password", b"cross_realm_trust_principal_password", "kdc_admin_password", b"kdc_admin_password", "realm", b"realm", "resource_info", b"resource_info"]) -> None: ...

global___ClusterKerberosAttributes = ClusterKerberosAttributes

@typing_extensions.final
class ClusterKeyValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___ClusterKeyValue = ClusterKeyValue

@typing_extensions.final
class ClusterHadoopJarStepConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    JAR_FIELD_NUMBER: builtins.int
    MAIN_CLASS_FIELD_NUMBER: builtins.int
    STEP_PROPERTIES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def args(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    jar: builtins.str
    main_class: builtins.str
    @property
    def step_properties(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClusterKeyValue]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        args: collections.abc.Iterable[builtins.str] | None = ...,
        jar: builtins.str = ...,
        main_class: builtins.str = ...,
        step_properties: collections.abc.Iterable[global___ClusterKeyValue] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["args", b"args", "jar", b"jar", "main_class", b"main_class", "resource_info", b"resource_info", "step_properties", b"step_properties"]) -> None: ...

global___ClusterHadoopJarStepConfig = ClusterHadoopJarStepConfig

@typing_extensions.final
class ClusterStepConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACTION_ON_FAILURE_FIELD_NUMBER: builtins.int
    HADOOP_JAR_STEP_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    action_on_failure: builtins.str
    @property
    def hadoop_jar_step(self) -> global___ClusterHadoopJarStepConfig: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        action_on_failure: builtins.str = ...,
        hadoop_jar_step: global___ClusterHadoopJarStepConfig | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["hadoop_jar_step", b"hadoop_jar_step", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action_on_failure", b"action_on_failure", "hadoop_jar_step", b"hadoop_jar_step", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ClusterStepConfig = ClusterStepConfig

@typing_extensions.final
class Cluster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AdditionalInfoEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ADDITIONAL_INFO_FIELD_NUMBER: builtins.int
    APPLICATIONS_FIELD_NUMBER: builtins.int
    AUTO_SCALING_ROLE_FIELD_NUMBER: builtins.int
    BOOTSTRAP_ACTIONS_FIELD_NUMBER: builtins.int
    CONFIGURATIONS_FIELD_NUMBER: builtins.int
    CUSTOM_AMI_ID_FIELD_NUMBER: builtins.int
    EBS_ROOT_VOLUME_SIZE_FIELD_NUMBER: builtins.int
    INSTANCES_FIELD_NUMBER: builtins.int
    JOB_FLOW_ROLE_FIELD_NUMBER: builtins.int
    KERBEROS_ATTRIBUTES_FIELD_NUMBER: builtins.int
    LOG_URI_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RELEASE_LABEL_FIELD_NUMBER: builtins.int
    SCALE_DOWN_BEHAVIOR_FIELD_NUMBER: builtins.int
    SECURITY_CONFIGURATION_FIELD_NUMBER: builtins.int
    SERVICE_ROLE_FIELD_NUMBER: builtins.int
    STEPS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    VISIBLE_TO_ALL_USERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def additional_info(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def applications(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClusterApplication]: ...
    auto_scaling_role: builtins.str
    @property
    def bootstrap_actions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClusterBootstrapActionConfig]: ...
    @property
    def configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClusterConfiguration]: ...
    custom_ami_id: builtins.str
    ebs_root_volume_size: builtins.int
    @property
    def instances(self) -> global___ClusterJobFlowInstancesConfig: ...
    job_flow_role: builtins.str
    @property
    def kerberos_attributes(self) -> global___ClusterKerberosAttributes: ...
    log_uri: builtins.str
    name: builtins.str
    release_label: builtins.str
    scale_down_behavior: builtins.str
    security_configuration: builtins.str
    service_role: builtins.str
    @property
    def steps(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClusterStepConfig]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    visible_to_all_users: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        additional_info: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        applications: collections.abc.Iterable[global___ClusterApplication] | None = ...,
        auto_scaling_role: builtins.str = ...,
        bootstrap_actions: collections.abc.Iterable[global___ClusterBootstrapActionConfig] | None = ...,
        configurations: collections.abc.Iterable[global___ClusterConfiguration] | None = ...,
        custom_ami_id: builtins.str = ...,
        ebs_root_volume_size: builtins.int = ...,
        instances: global___ClusterJobFlowInstancesConfig | None = ...,
        job_flow_role: builtins.str = ...,
        kerberos_attributes: global___ClusterKerberosAttributes | None = ...,
        log_uri: builtins.str = ...,
        name: builtins.str = ...,
        release_label: builtins.str = ...,
        scale_down_behavior: builtins.str = ...,
        security_configuration: builtins.str = ...,
        service_role: builtins.str = ...,
        steps: collections.abc.Iterable[global___ClusterStepConfig] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        visible_to_all_users: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["instances", b"instances", "kerberos_attributes", b"kerberos_attributes", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional_info", b"additional_info", "applications", b"applications", "auto_scaling_role", b"auto_scaling_role", "bootstrap_actions", b"bootstrap_actions", "configurations", b"configurations", "custom_ami_id", b"custom_ami_id", "ebs_root_volume_size", b"ebs_root_volume_size", "instances", b"instances", "job_flow_role", b"job_flow_role", "kerberos_attributes", b"kerberos_attributes", "log_uri", b"log_uri", "name", b"name", "release_label", b"release_label", "resource_info", b"resource_info", "scale_down_behavior", b"scale_down_behavior", "security_configuration", b"security_configuration", "service_role", b"service_role", "steps", b"steps", "tags", b"tags", "visible_to_all_users", b"visible_to_all_users"]) -> None: ...

global___Cluster = Cluster

@typing_extensions.final
class EMR(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_FIELD_NUMBER: builtins.int
    INSTANCE_FLEET_CONFIG_FIELD_NUMBER: builtins.int
    INSTANCE_GROUP_CONFIG_FIELD_NUMBER: builtins.int
    SECURITY_CONFIGURATION_FIELD_NUMBER: builtins.int
    STEP_FIELD_NUMBER: builtins.int
    @property
    def cluster(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Cluster]: ...
    @property
    def instance_fleet_config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InstanceFleetConfig]: ...
    @property
    def instance_group_config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InstanceGroupConfig]: ...
    @property
    def security_configuration(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SecurityConfiguration]: ...
    @property
    def step(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Step]: ...
    def __init__(
        self,
        *,
        cluster: collections.abc.Iterable[global___Cluster] | None = ...,
        instance_fleet_config: collections.abc.Iterable[global___InstanceFleetConfig] | None = ...,
        instance_group_config: collections.abc.Iterable[global___InstanceGroupConfig] | None = ...,
        security_configuration: collections.abc.Iterable[global___SecurityConfiguration] | None = ...,
        step: collections.abc.Iterable[global___Step] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster", b"cluster", "instance_fleet_config", b"instance_fleet_config", "instance_group_config", b"instance_group_config", "security_configuration", b"security_configuration", "step", b"step"]) -> None: ...

global___EMR = EMR

@typing_extensions.final
class InstanceFleetConfigConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ConfigurationPropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLASSIFICATION_FIELD_NUMBER: builtins.int
    CONFIGURATION_PROPERTIES_FIELD_NUMBER: builtins.int
    CONFIGURATIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    classification: builtins.str
    @property
    def configuration_properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InstanceFleetConfigConfiguration]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        classification: builtins.str = ...,
        configuration_properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        configurations: collections.abc.Iterable[global___InstanceFleetConfigConfiguration] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["classification", b"classification", "configuration_properties", b"configuration_properties", "configurations", b"configurations", "resource_info", b"resource_info"]) -> None: ...

global___InstanceFleetConfigConfiguration = InstanceFleetConfigConfiguration

@typing_extensions.final
class InstanceFleetConfigVolumeSpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IOPS_FIELD_NUMBER: builtins.int
    SIZE_IN_GB_FIELD_NUMBER: builtins.int
    VOLUME_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    iops: builtins.int
    size_in_gb: builtins.int
    volume_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        iops: builtins.int = ...,
        size_in_gb: builtins.int = ...,
        volume_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["iops", b"iops", "resource_info", b"resource_info", "size_in_gb", b"size_in_gb", "volume_type", b"volume_type"]) -> None: ...

global___InstanceFleetConfigVolumeSpecification = InstanceFleetConfigVolumeSpecification

@typing_extensions.final
class InstanceFleetConfigEbsBlockDeviceConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VOLUME_SPECIFICATION_FIELD_NUMBER: builtins.int
    VOLUMES_PER_INSTANCE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def volume_specification(self) -> global___InstanceFleetConfigVolumeSpecification: ...
    volumes_per_instance: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        volume_specification: global___InstanceFleetConfigVolumeSpecification | None = ...,
        volumes_per_instance: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "volume_specification", b"volume_specification"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "volume_specification", b"volume_specification", "volumes_per_instance", b"volumes_per_instance"]) -> None: ...

global___InstanceFleetConfigEbsBlockDeviceConfig = InstanceFleetConfigEbsBlockDeviceConfig

@typing_extensions.final
class InstanceFleetConfigEbsConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EBS_BLOCK_DEVICE_CONFIGS_FIELD_NUMBER: builtins.int
    EBS_OPTIMIZED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def ebs_block_device_configs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InstanceFleetConfigEbsBlockDeviceConfig]: ...
    ebs_optimized: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        ebs_block_device_configs: collections.abc.Iterable[global___InstanceFleetConfigEbsBlockDeviceConfig] | None = ...,
        ebs_optimized: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ebs_block_device_configs", b"ebs_block_device_configs", "ebs_optimized", b"ebs_optimized", "resource_info", b"resource_info"]) -> None: ...

global___InstanceFleetConfigEbsConfiguration = InstanceFleetConfigEbsConfiguration

@typing_extensions.final
class InstanceFleetConfigInstanceTypeConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BID_PRICE_FIELD_NUMBER: builtins.int
    BID_PRICE_AS_PERCENTAGE_OF_ON_DEMAND_PRICE_FIELD_NUMBER: builtins.int
    CONFIGURATIONS_FIELD_NUMBER: builtins.int
    EBS_CONFIGURATION_FIELD_NUMBER: builtins.int
    INSTANCE_TYPE_FIELD_NUMBER: builtins.int
    WEIGHTED_CAPACITY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    bid_price: builtins.str
    bid_price_as_percentage_of_on_demand_price: builtins.float
    @property
    def configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InstanceFleetConfigConfiguration]: ...
    @property
    def ebs_configuration(self) -> global___InstanceFleetConfigEbsConfiguration: ...
    instance_type: builtins.str
    weighted_capacity: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        bid_price: builtins.str = ...,
        bid_price_as_percentage_of_on_demand_price: builtins.float = ...,
        configurations: collections.abc.Iterable[global___InstanceFleetConfigConfiguration] | None = ...,
        ebs_configuration: global___InstanceFleetConfigEbsConfiguration | None = ...,
        instance_type: builtins.str = ...,
        weighted_capacity: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ebs_configuration", b"ebs_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bid_price", b"bid_price", "bid_price_as_percentage_of_on_demand_price", b"bid_price_as_percentage_of_on_demand_price", "configurations", b"configurations", "ebs_configuration", b"ebs_configuration", "instance_type", b"instance_type", "resource_info", b"resource_info", "weighted_capacity", b"weighted_capacity"]) -> None: ...

global___InstanceFleetConfigInstanceTypeConfig = InstanceFleetConfigInstanceTypeConfig

@typing_extensions.final
class InstanceFleetConfigSpotProvisioningSpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BLOCK_DURATION_MINUTES_FIELD_NUMBER: builtins.int
    TIMEOUT_ACTION_FIELD_NUMBER: builtins.int
    TIMEOUT_DURATION_MINUTES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    block_duration_minutes: builtins.int
    timeout_action: builtins.str
    timeout_duration_minutes: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        block_duration_minutes: builtins.int = ...,
        timeout_action: builtins.str = ...,
        timeout_duration_minutes: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["block_duration_minutes", b"block_duration_minutes", "resource_info", b"resource_info", "timeout_action", b"timeout_action", "timeout_duration_minutes", b"timeout_duration_minutes"]) -> None: ...

global___InstanceFleetConfigSpotProvisioningSpecification = InstanceFleetConfigSpotProvisioningSpecification

@typing_extensions.final
class InstanceFleetConfigInstanceFleetProvisioningSpecifications(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SPOT_SPECIFICATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def spot_specification(self) -> global___InstanceFleetConfigSpotProvisioningSpecification: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        spot_specification: global___InstanceFleetConfigSpotProvisioningSpecification | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "spot_specification", b"spot_specification"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "spot_specification", b"spot_specification"]) -> None: ...

global___InstanceFleetConfigInstanceFleetProvisioningSpecifications = InstanceFleetConfigInstanceFleetProvisioningSpecifications

@typing_extensions.final
class InstanceFleetConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    INSTANCE_FLEET_TYPE_FIELD_NUMBER: builtins.int
    INSTANCE_TYPE_CONFIGS_FIELD_NUMBER: builtins.int
    LAUNCH_SPECIFICATIONS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TARGET_ON_DEMAND_CAPACITY_FIELD_NUMBER: builtins.int
    TARGET_SPOT_CAPACITY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    cluster_id: builtins.str
    instance_fleet_type: builtins.str
    @property
    def instance_type_configs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InstanceFleetConfigInstanceTypeConfig]: ...
    @property
    def launch_specifications(self) -> global___InstanceFleetConfigInstanceFleetProvisioningSpecifications: ...
    name: builtins.str
    target_on_demand_capacity: builtins.int
    target_spot_capacity: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cluster_id: builtins.str = ...,
        instance_fleet_type: builtins.str = ...,
        instance_type_configs: collections.abc.Iterable[global___InstanceFleetConfigInstanceTypeConfig] | None = ...,
        launch_specifications: global___InstanceFleetConfigInstanceFleetProvisioningSpecifications | None = ...,
        name: builtins.str = ...,
        target_on_demand_capacity: builtins.int = ...,
        target_spot_capacity: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["launch_specifications", b"launch_specifications", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_id", b"cluster_id", "instance_fleet_type", b"instance_fleet_type", "instance_type_configs", b"instance_type_configs", "launch_specifications", b"launch_specifications", "name", b"name", "resource_info", b"resource_info", "target_on_demand_capacity", b"target_on_demand_capacity", "target_spot_capacity", b"target_spot_capacity"]) -> None: ...

global___InstanceFleetConfig = InstanceFleetConfig

@typing_extensions.final
class InstanceGroupConfigScalingConstraints(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MAX_CAPACITY_FIELD_NUMBER: builtins.int
    MIN_CAPACITY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    max_capacity: builtins.int
    min_capacity: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        max_capacity: builtins.int = ...,
        min_capacity: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_capacity", b"max_capacity", "min_capacity", b"min_capacity", "resource_info", b"resource_info"]) -> None: ...

global___InstanceGroupConfigScalingConstraints = InstanceGroupConfigScalingConstraints

@typing_extensions.final
class InstanceGroupConfigSimpleScalingPolicyConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ADJUSTMENT_TYPE_FIELD_NUMBER: builtins.int
    COOL_DOWN_FIELD_NUMBER: builtins.int
    SCALING_ADJUSTMENT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    adjustment_type: builtins.str
    cool_down: builtins.int
    scaling_adjustment: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        adjustment_type: builtins.str = ...,
        cool_down: builtins.int = ...,
        scaling_adjustment: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["adjustment_type", b"adjustment_type", "cool_down", b"cool_down", "resource_info", b"resource_info", "scaling_adjustment", b"scaling_adjustment"]) -> None: ...

global___InstanceGroupConfigSimpleScalingPolicyConfiguration = InstanceGroupConfigSimpleScalingPolicyConfiguration

@typing_extensions.final
class InstanceGroupConfigScalingAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MARKET_FIELD_NUMBER: builtins.int
    SIMPLE_SCALING_POLICY_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    market: builtins.str
    @property
    def simple_scaling_policy_configuration(self) -> global___InstanceGroupConfigSimpleScalingPolicyConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        market: builtins.str = ...,
        simple_scaling_policy_configuration: global___InstanceGroupConfigSimpleScalingPolicyConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "simple_scaling_policy_configuration", b"simple_scaling_policy_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["market", b"market", "resource_info", b"resource_info", "simple_scaling_policy_configuration", b"simple_scaling_policy_configuration"]) -> None: ...

global___InstanceGroupConfigScalingAction = InstanceGroupConfigScalingAction

@typing_extensions.final
class InstanceGroupConfigMetricDimension(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___InstanceGroupConfigMetricDimension = InstanceGroupConfigMetricDimension

@typing_extensions.final
class InstanceGroupConfigCloudWatchAlarmDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COMPARISON_OPERATOR_FIELD_NUMBER: builtins.int
    DIMENSIONS_FIELD_NUMBER: builtins.int
    EVALUATION_PERIODS_FIELD_NUMBER: builtins.int
    METRIC_NAME_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    PERIOD_FIELD_NUMBER: builtins.int
    STATISTIC_FIELD_NUMBER: builtins.int
    THRESHOLD_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    comparison_operator: builtins.str
    @property
    def dimensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InstanceGroupConfigMetricDimension]: ...
    evaluation_periods: builtins.int
    metric_name: builtins.str
    namespace: builtins.str
    period: builtins.int
    statistic: builtins.str
    threshold: builtins.float
    unit: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        comparison_operator: builtins.str = ...,
        dimensions: collections.abc.Iterable[global___InstanceGroupConfigMetricDimension] | None = ...,
        evaluation_periods: builtins.int = ...,
        metric_name: builtins.str = ...,
        namespace: builtins.str = ...,
        period: builtins.int = ...,
        statistic: builtins.str = ...,
        threshold: builtins.float = ...,
        unit: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["comparison_operator", b"comparison_operator", "dimensions", b"dimensions", "evaluation_periods", b"evaluation_periods", "metric_name", b"metric_name", "namespace", b"namespace", "period", b"period", "resource_info", b"resource_info", "statistic", b"statistic", "threshold", b"threshold", "unit", b"unit"]) -> None: ...

global___InstanceGroupConfigCloudWatchAlarmDefinition = InstanceGroupConfigCloudWatchAlarmDefinition

@typing_extensions.final
class InstanceGroupConfigScalingTrigger(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLOUD_WATCH_ALARM_DEFINITION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def cloud_watch_alarm_definition(self) -> global___InstanceGroupConfigCloudWatchAlarmDefinition: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cloud_watch_alarm_definition: global___InstanceGroupConfigCloudWatchAlarmDefinition | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cloud_watch_alarm_definition", b"cloud_watch_alarm_definition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_watch_alarm_definition", b"cloud_watch_alarm_definition", "resource_info", b"resource_info"]) -> None: ...

global___InstanceGroupConfigScalingTrigger = InstanceGroupConfigScalingTrigger

@typing_extensions.final
class InstanceGroupConfigScalingRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TRIGGER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def action(self) -> global___InstanceGroupConfigScalingAction: ...
    description: builtins.str
    name: builtins.str
    @property
    def trigger(self) -> global___InstanceGroupConfigScalingTrigger: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        action: global___InstanceGroupConfigScalingAction | None = ...,
        description: builtins.str = ...,
        name: builtins.str = ...,
        trigger: global___InstanceGroupConfigScalingTrigger | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["action", b"action", "resource_info", b"resource_info", "trigger", b"trigger"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "description", b"description", "name", b"name", "resource_info", b"resource_info", "trigger", b"trigger"]) -> None: ...

global___InstanceGroupConfigScalingRule = InstanceGroupConfigScalingRule

@typing_extensions.final
class InstanceGroupConfigAutoScalingPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONSTRAINTS_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def constraints(self) -> global___InstanceGroupConfigScalingConstraints: ...
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InstanceGroupConfigScalingRule]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        constraints: global___InstanceGroupConfigScalingConstraints | None = ...,
        rules: collections.abc.Iterable[global___InstanceGroupConfigScalingRule] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["constraints", b"constraints", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["constraints", b"constraints", "resource_info", b"resource_info", "rules", b"rules"]) -> None: ...

global___InstanceGroupConfigAutoScalingPolicy = InstanceGroupConfigAutoScalingPolicy

@typing_extensions.final
class InstanceGroupConfigConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ConfigurationPropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLASSIFICATION_FIELD_NUMBER: builtins.int
    CONFIGURATION_PROPERTIES_FIELD_NUMBER: builtins.int
    CONFIGURATIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    classification: builtins.str
    @property
    def configuration_properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InstanceGroupConfigConfiguration]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        classification: builtins.str = ...,
        configuration_properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        configurations: collections.abc.Iterable[global___InstanceGroupConfigConfiguration] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["classification", b"classification", "configuration_properties", b"configuration_properties", "configurations", b"configurations", "resource_info", b"resource_info"]) -> None: ...

global___InstanceGroupConfigConfiguration = InstanceGroupConfigConfiguration

@typing_extensions.final
class InstanceGroupConfigVolumeSpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IOPS_FIELD_NUMBER: builtins.int
    SIZE_IN_GB_FIELD_NUMBER: builtins.int
    VOLUME_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    iops: builtins.int
    size_in_gb: builtins.int
    volume_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        iops: builtins.int = ...,
        size_in_gb: builtins.int = ...,
        volume_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["iops", b"iops", "resource_info", b"resource_info", "size_in_gb", b"size_in_gb", "volume_type", b"volume_type"]) -> None: ...

global___InstanceGroupConfigVolumeSpecification = InstanceGroupConfigVolumeSpecification

@typing_extensions.final
class InstanceGroupConfigEbsBlockDeviceConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VOLUME_SPECIFICATION_FIELD_NUMBER: builtins.int
    VOLUMES_PER_INSTANCE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def volume_specification(self) -> global___InstanceGroupConfigVolumeSpecification: ...
    volumes_per_instance: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        volume_specification: global___InstanceGroupConfigVolumeSpecification | None = ...,
        volumes_per_instance: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "volume_specification", b"volume_specification"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "volume_specification", b"volume_specification", "volumes_per_instance", b"volumes_per_instance"]) -> None: ...

global___InstanceGroupConfigEbsBlockDeviceConfig = InstanceGroupConfigEbsBlockDeviceConfig

@typing_extensions.final
class InstanceGroupConfigEbsConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EBS_BLOCK_DEVICE_CONFIGS_FIELD_NUMBER: builtins.int
    EBS_OPTIMIZED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def ebs_block_device_configs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InstanceGroupConfigEbsBlockDeviceConfig]: ...
    ebs_optimized: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        ebs_block_device_configs: collections.abc.Iterable[global___InstanceGroupConfigEbsBlockDeviceConfig] | None = ...,
        ebs_optimized: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ebs_block_device_configs", b"ebs_block_device_configs", "ebs_optimized", b"ebs_optimized", "resource_info", b"resource_info"]) -> None: ...

global___InstanceGroupConfigEbsConfiguration = InstanceGroupConfigEbsConfiguration

@typing_extensions.final
class InstanceGroupConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AUTO_SCALING_POLICY_FIELD_NUMBER: builtins.int
    BID_PRICE_FIELD_NUMBER: builtins.int
    CONFIGURATIONS_FIELD_NUMBER: builtins.int
    EBS_CONFIGURATION_FIELD_NUMBER: builtins.int
    INSTANCE_COUNT_FIELD_NUMBER: builtins.int
    INSTANCE_ROLE_FIELD_NUMBER: builtins.int
    INSTANCE_TYPE_FIELD_NUMBER: builtins.int
    JOB_FLOW_ID_FIELD_NUMBER: builtins.int
    MARKET_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def auto_scaling_policy(self) -> global___InstanceGroupConfigAutoScalingPolicy: ...
    bid_price: builtins.str
    @property
    def configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InstanceGroupConfigConfiguration]: ...
    @property
    def ebs_configuration(self) -> global___InstanceGroupConfigEbsConfiguration: ...
    instance_count: builtins.int
    instance_role: builtins.str
    instance_type: builtins.str
    job_flow_id: builtins.str
    market: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        auto_scaling_policy: global___InstanceGroupConfigAutoScalingPolicy | None = ...,
        bid_price: builtins.str = ...,
        configurations: collections.abc.Iterable[global___InstanceGroupConfigConfiguration] | None = ...,
        ebs_configuration: global___InstanceGroupConfigEbsConfiguration | None = ...,
        instance_count: builtins.int = ...,
        instance_role: builtins.str = ...,
        instance_type: builtins.str = ...,
        job_flow_id: builtins.str = ...,
        market: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auto_scaling_policy", b"auto_scaling_policy", "ebs_configuration", b"ebs_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_scaling_policy", b"auto_scaling_policy", "bid_price", b"bid_price", "configurations", b"configurations", "ebs_configuration", b"ebs_configuration", "instance_count", b"instance_count", "instance_role", b"instance_role", "instance_type", b"instance_type", "job_flow_id", b"job_flow_id", "market", b"market", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___InstanceGroupConfig = InstanceGroupConfig

@typing_extensions.final
class SecurityConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SecurityConfigurationEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SECURITY_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def security_configuration(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        security_configuration: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "security_configuration", b"security_configuration"]) -> None: ...

global___SecurityConfiguration = SecurityConfiguration

@typing_extensions.final
class StepKeyValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___StepKeyValue = StepKeyValue

@typing_extensions.final
class StepHadoopJarStepConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    JAR_FIELD_NUMBER: builtins.int
    MAIN_CLASS_FIELD_NUMBER: builtins.int
    STEP_PROPERTIES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def args(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    jar: builtins.str
    main_class: builtins.str
    @property
    def step_properties(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StepKeyValue]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        args: collections.abc.Iterable[builtins.str] | None = ...,
        jar: builtins.str = ...,
        main_class: builtins.str = ...,
        step_properties: collections.abc.Iterable[global___StepKeyValue] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["args", b"args", "jar", b"jar", "main_class", b"main_class", "resource_info", b"resource_info", "step_properties", b"step_properties"]) -> None: ...

global___StepHadoopJarStepConfig = StepHadoopJarStepConfig

@typing_extensions.final
class Step(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACTION_ON_FAILURE_FIELD_NUMBER: builtins.int
    HADOOP_JAR_STEP_FIELD_NUMBER: builtins.int
    JOB_FLOW_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    action_on_failure: builtins.str
    @property
    def hadoop_jar_step(self) -> global___StepHadoopJarStepConfig: ...
    job_flow_id: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        action_on_failure: builtins.str = ...,
        hadoop_jar_step: global___StepHadoopJarStepConfig | None = ...,
        job_flow_id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["hadoop_jar_step", b"hadoop_jar_step", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action_on_failure", b"action_on_failure", "hadoop_jar_step", b"hadoop_jar_step", "job_flow_id", b"job_flow_id", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___Step = Step



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ApplicationCustomComponent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COMPONENT_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_LIST_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    component_name: builtins.str
    @property
    def resource_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        component_name: builtins.str = ...,
        resource_list: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["component_name", b"component_name", "resource_info", b"resource_info", "resource_list", b"resource_list"]) -> None: ...

global___ApplicationCustomComponent = ApplicationCustomComponent

@typing_extensions.final
class ApplicationLogPattern(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PATTERN_NAME_FIELD_NUMBER: builtins.int
    PATTERN_FIELD_NUMBER: builtins.int
    RANK_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    pattern_name: builtins.str
    pattern: builtins.str
    rank: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        pattern_name: builtins.str = ...,
        pattern: builtins.str = ...,
        rank: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pattern", b"pattern", "pattern_name", b"pattern_name", "rank", b"rank", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationLogPattern = ApplicationLogPattern

@typing_extensions.final
class ApplicationLogPatternSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PATTERN_SET_NAME_FIELD_NUMBER: builtins.int
    LOG_PATTERNS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    pattern_set_name: builtins.str
    @property
    def log_patterns(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationLogPattern]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        pattern_set_name: builtins.str = ...,
        log_patterns: collections.abc.Iterable[global___ApplicationLogPattern] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["log_patterns", b"log_patterns", "pattern_set_name", b"pattern_set_name", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationLogPatternSet = ApplicationLogPatternSet

@typing_extensions.final
class ApplicationAlarmMetric(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALARM_METRIC_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    alarm_metric_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        alarm_metric_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alarm_metric_name", b"alarm_metric_name", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationAlarmMetric = ApplicationAlarmMetric

@typing_extensions.final
class ApplicationLog(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOG_GROUP_NAME_FIELD_NUMBER: builtins.int
    LOG_PATH_FIELD_NUMBER: builtins.int
    LOG_TYPE_FIELD_NUMBER: builtins.int
    ENCODING_FIELD_NUMBER: builtins.int
    PATTERN_SET_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    log_group_name: builtins.str
    log_path: builtins.str
    log_type: builtins.str
    encoding: builtins.str
    pattern_set: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        log_group_name: builtins.str = ...,
        log_path: builtins.str = ...,
        log_type: builtins.str = ...,
        encoding: builtins.str = ...,
        pattern_set: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["encoding", b"encoding", "log_group_name", b"log_group_name", "log_path", b"log_path", "log_type", b"log_type", "pattern_set", b"pattern_set", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationLog = ApplicationLog

@typing_extensions.final
class ApplicationWindowsEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOG_GROUP_NAME_FIELD_NUMBER: builtins.int
    EVENT_NAME_FIELD_NUMBER: builtins.int
    EVENT_LEVELS_FIELD_NUMBER: builtins.int
    PATTERN_SET_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    log_group_name: builtins.str
    event_name: builtins.str
    @property
    def event_levels(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    pattern_set: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        log_group_name: builtins.str = ...,
        event_name: builtins.str = ...,
        event_levels: collections.abc.Iterable[builtins.str] | None = ...,
        pattern_set: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["event_levels", b"event_levels", "event_name", b"event_name", "log_group_name", b"log_group_name", "pattern_set", b"pattern_set", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationWindowsEvent = ApplicationWindowsEvent

@typing_extensions.final
class ApplicationAlarm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALARM_NAME_FIELD_NUMBER: builtins.int
    SEVERITY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    alarm_name: builtins.str
    severity: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        alarm_name: builtins.str = ...,
        severity: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alarm_name", b"alarm_name", "resource_info", b"resource_info", "severity", b"severity"]) -> None: ...

global___ApplicationAlarm = ApplicationAlarm

@typing_extensions.final
class ApplicationConfigurationDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALARM_METRICS_FIELD_NUMBER: builtins.int
    LOGS_FIELD_NUMBER: builtins.int
    WINDOWS_EVENTS_FIELD_NUMBER: builtins.int
    ALARMS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def alarm_metrics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationAlarmMetric]: ...
    @property
    def logs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationLog]: ...
    @property
    def windows_events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationWindowsEvent]: ...
    @property
    def alarms(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationAlarm]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        alarm_metrics: collections.abc.Iterable[global___ApplicationAlarmMetric] | None = ...,
        logs: collections.abc.Iterable[global___ApplicationLog] | None = ...,
        windows_events: collections.abc.Iterable[global___ApplicationWindowsEvent] | None = ...,
        alarms: collections.abc.Iterable[global___ApplicationAlarm] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alarm_metrics", b"alarm_metrics", "alarms", b"alarms", "logs", b"logs", "resource_info", b"resource_info", "windows_events", b"windows_events"]) -> None: ...

global___ApplicationConfigurationDetails = ApplicationConfigurationDetails

@typing_extensions.final
class ApplicationSubComponentConfigurationDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALARM_METRICS_FIELD_NUMBER: builtins.int
    LOGS_FIELD_NUMBER: builtins.int
    WINDOWS_EVENTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def alarm_metrics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationAlarmMetric]: ...
    @property
    def logs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationLog]: ...
    @property
    def windows_events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationWindowsEvent]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        alarm_metrics: collections.abc.Iterable[global___ApplicationAlarmMetric] | None = ...,
        logs: collections.abc.Iterable[global___ApplicationLog] | None = ...,
        windows_events: collections.abc.Iterable[global___ApplicationWindowsEvent] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alarm_metrics", b"alarm_metrics", "logs", b"logs", "resource_info", b"resource_info", "windows_events", b"windows_events"]) -> None: ...

global___ApplicationSubComponentConfigurationDetails = ApplicationSubComponentConfigurationDetails

@typing_extensions.final
class ApplicationSubComponentTypeConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SUB_COMPONENT_TYPE_FIELD_NUMBER: builtins.int
    SUB_COMPONENT_CONFIGURATION_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    sub_component_type: builtins.str
    @property
    def sub_component_configuration_details(self) -> global___ApplicationSubComponentConfigurationDetails: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        sub_component_type: builtins.str = ...,
        sub_component_configuration_details: global___ApplicationSubComponentConfigurationDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "sub_component_configuration_details", b"sub_component_configuration_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "sub_component_configuration_details", b"sub_component_configuration_details", "sub_component_type", b"sub_component_type"]) -> None: ...

global___ApplicationSubComponentTypeConfiguration = ApplicationSubComponentTypeConfiguration

@typing_extensions.final
class ApplicationComponentConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONFIGURATION_DETAILS_FIELD_NUMBER: builtins.int
    SUB_COMPONENT_TYPE_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def configuration_details(self) -> global___ApplicationConfigurationDetails: ...
    @property
    def sub_component_type_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationSubComponentTypeConfiguration]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        configuration_details: global___ApplicationConfigurationDetails | None = ...,
        sub_component_type_configurations: collections.abc.Iterable[global___ApplicationSubComponentTypeConfiguration] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["configuration_details", b"configuration_details", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["configuration_details", b"configuration_details", "resource_info", b"resource_info", "sub_component_type_configurations", b"sub_component_type_configurations"]) -> None: ...

global___ApplicationComponentConfiguration = ApplicationComponentConfiguration

@typing_extensions.final
class ApplicationComponentMonitoringSetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COMPONENT_NAME_FIELD_NUMBER: builtins.int
    COMPONENT_ARN_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    COMPONENT_CONFIGURATION_MODE_FIELD_NUMBER: builtins.int
    DEFAULT_OVERWRITE_COMPONENT_CONFIGURATION_FIELD_NUMBER: builtins.int
    CUSTOM_COMPONENT_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    component_name: builtins.str
    component_arn: builtins.str
    tier: builtins.str
    component_configuration_mode: builtins.str
    @property
    def default_overwrite_component_configuration(self) -> global___ApplicationComponentConfiguration: ...
    @property
    def custom_component_configuration(self) -> global___ApplicationComponentConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        component_name: builtins.str = ...,
        component_arn: builtins.str = ...,
        tier: builtins.str = ...,
        component_configuration_mode: builtins.str = ...,
        default_overwrite_component_configuration: global___ApplicationComponentConfiguration | None = ...,
        custom_component_configuration: global___ApplicationComponentConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["custom_component_configuration", b"custom_component_configuration", "default_overwrite_component_configuration", b"default_overwrite_component_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["component_arn", b"component_arn", "component_configuration_mode", b"component_configuration_mode", "component_name", b"component_name", "custom_component_configuration", b"custom_component_configuration", "default_overwrite_component_configuration", b"default_overwrite_component_configuration", "resource_info", b"resource_info", "tier", b"tier"]) -> None: ...

global___ApplicationComponentMonitoringSetting = ApplicationComponentMonitoringSetting

@typing_extensions.final
class Application(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_NAME_FIELD_NUMBER: builtins.int
    CWE_MONITOR_ENABLED_FIELD_NUMBER: builtins.int
    OPS_CENTER_ENABLED_FIELD_NUMBER: builtins.int
    OPS_ITEM_SNS_TOPIC_ARN_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    CUSTOM_COMPONENTS_FIELD_NUMBER: builtins.int
    LOG_PATTERN_SETS_FIELD_NUMBER: builtins.int
    AUTO_CONFIGURATION_ENABLED_FIELD_NUMBER: builtins.int
    COMPONENT_MONITORING_SETTINGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    resource_group_name: builtins.str
    cwe_monitor_enabled: builtins.bool
    ops_center_enabled: builtins.bool
    ops_item_sns_topic_arn: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def custom_components(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationCustomComponent]: ...
    @property
    def log_pattern_sets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationLogPatternSet]: ...
    auto_configuration_enabled: builtins.bool
    @property
    def component_monitoring_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationComponentMonitoringSetting]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        resource_group_name: builtins.str = ...,
        cwe_monitor_enabled: builtins.bool = ...,
        ops_center_enabled: builtins.bool = ...,
        ops_item_sns_topic_arn: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        custom_components: collections.abc.Iterable[global___ApplicationCustomComponent] | None = ...,
        log_pattern_sets: collections.abc.Iterable[global___ApplicationLogPatternSet] | None = ...,
        auto_configuration_enabled: builtins.bool = ...,
        component_monitoring_settings: collections.abc.Iterable[global___ApplicationComponentMonitoringSetting] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_configuration_enabled", b"auto_configuration_enabled", "component_monitoring_settings", b"component_monitoring_settings", "custom_components", b"custom_components", "cwe_monitor_enabled", b"cwe_monitor_enabled", "log_pattern_sets", b"log_pattern_sets", "ops_center_enabled", b"ops_center_enabled", "ops_item_sns_topic_arn", b"ops_item_sns_topic_arn", "resource_group_name", b"resource_group_name", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Application = Application

@typing_extensions.final
class ApplicationInsights(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    @property
    def application(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Application]: ...
    def __init__(
        self,
        *,
        application: collections.abc.Iterable[global___Application] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application"]) -> None: ...

global___ApplicationInsights = ApplicationInsights



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_firebaserules.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bgcp/gcp_firebaserules.proto\x12\x1doak9.tython.gcp.firebaserules\x1a\x13shared/shared.proto\"O\n\x1d\x46irebaserulesReleaseXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x9c\x02\n\x14\x46irebaserulesRelease\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x10\n\x08\x64isabled\x18\x02 \x01(\x08\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x14\n\x0cruleset_name\x18\x06 \x01(\t\x12\x13\n\x0bupdate_time\x18\x07 \x01(\t\x12N\n\x08timeouts\x18\x08 \x01(\x0b\x32<.oak9.tython.gcp.firebaserules.FirebaserulesReleaseXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"W\n!FirebaserulesRulesetXSourceXFiles\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x13\n\x0b\x66ingerprint\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x80\x01\n\x1b\x46irebaserulesRulesetXSource\x12\x10\n\x08language\x18\x01 \x01(\t\x12O\n\x05\x66iles\x18\x02 \x03(\x0b\x32@.oak9.tython.gcp.firebaserules.FirebaserulesRulesetXSourceXFiles\"?\n\x1d\x46irebaserulesRulesetXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xb1\x03\n\x14\x46irebaserulesRuleset\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12S\n\x08metadata\x18\x03 \x03(\x0b\x32\x41.oak9.tython.gcp.firebaserules.FirebaserulesRuleset.MetadataEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12J\n\x06source\x18\x06 \x01(\x0b\x32:.oak9.tython.gcp.firebaserules.FirebaserulesRulesetXSource\x12N\n\x08timeouts\x18\x07 \x01(\x0b\x32<.oak9.tython.gcp.firebaserules.FirebaserulesRulesetXTimeouts\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_firebaserules_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FIREBASERULESRULESET_METADATAENTRY._options = None
  _FIREBASERULESRULESET_METADATAENTRY._serialized_options = b'8\001'
  _FIREBASERULESRELEASEXTIMEOUTS._serialized_start=83
  _FIREBASERULESRELEASEXTIMEOUTS._serialized_end=162
  _FIREBASERULESRELEASE._serialized_start=165
  _FIREBASERULESRELEASE._serialized_end=449
  _FIREBASERULESRULESETXSOURCEXFILES._serialized_start=451
  _FIREBASERULESRULESETXSOURCEXFILES._serialized_end=538
  _FIREBASERULESRULESETXSOURCE._serialized_start=541
  _FIREBASERULESRULESETXSOURCE._serialized_end=669
  _FIREBASERULESRULESETXTIMEOUTS._serialized_start=671
  _FIREBASERULESRULESETXTIMEOUTS._serialized_end=734
  _FIREBASERULESRULESET._serialized_start=737
  _FIREBASERULESRULESET._serialized_end=1170
  _FIREBASERULESRULESET_METADATAENTRY._serialized_start=1123
  _FIREBASERULESRULESET_METADATAENTRY._serialized_end=1170
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_resource.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1egcp/gcp_compute_resource.proto\x12 oak9.tython.gcp.compute_resource\x1a\x13shared/shared.proto\"v\n*ComputeResourcePolicyXGroupPlacementPolicy\x12!\n\x19\x61vailability_domain_count\x18\x01 \x01(\x01\x12\x13\n\x0b\x63ollocation\x18\x02 \x01(\t\x12\x10\n\x08vm_count\x18\x03 \x01(\x01\"P\n<ComputeResourcePolicyXInstanceSchedulePolicyXVmStartSchedule\x12\x10\n\x08schedule\x18\x01 \x01(\t\"O\n;ComputeResourcePolicyXInstanceSchedulePolicyXVmStopSchedule\x12\x10\n\x08schedule\x18\x01 \x01(\t\"\xe2\x02\n,ComputeResourcePolicyXInstanceSchedulePolicy\x12\x17\n\x0f\x65xpiration_time\x18\x01 \x01(\t\x12\x12\n\nstart_time\x18\x02 \x01(\t\x12\x11\n\ttime_zone\x18\x03 \x01(\t\x12y\n\x11vm_start_schedule\x18\x04 \x01(\x0b\x32^.oak9.tython.gcp.compute_resource.ComputeResourcePolicyXInstanceSchedulePolicyXVmStartSchedule\x12w\n\x10vm_stop_schedule\x18\x05 \x01(\x0b\x32].oak9.tython.gcp.compute_resource.ComputeResourcePolicyXInstanceSchedulePolicyXVmStopSchedule\"y\n<ComputeResourcePolicyXSnapshotSchedulePolicyXRetentionPolicy\x12\x1a\n\x12max_retention_days\x18\x01 \x01(\x01\x12\x1d\n\x15on_source_disk_delete\x18\x02 \x01(\t\"p\nCComputeResourcePolicyXSnapshotSchedulePolicyXScheduleXDailySchedule\x12\x15\n\rdays_in_cycle\x18\x01 \x01(\x01\x12\x12\n\nstart_time\x18\x02 \x01(\t\"r\nDComputeResourcePolicyXSnapshotSchedulePolicyXScheduleXHourlySchedule\x12\x16\n\x0ehours_in_cycle\x18\x01 \x01(\x01\x12\x12\n\nstart_time\x18\x02 \x01(\t\"r\nOComputeResourcePolicyXSnapshotSchedulePolicyXScheduleXWeeklyScheduleXDayOfWeeks\x12\x0b\n\x03\x64\x61y\x18\x01 \x01(\t\x12\x12\n\nstart_time\x18\x02 \x01(\t\"\xd0\x01\nDComputeResourcePolicyXSnapshotSchedulePolicyXScheduleXWeeklySchedule\x12\x87\x01\n\x0c\x64\x61y_of_weeks\x18\x01 \x03(\x0b\x32q.oak9.tython.gcp.compute_resource.ComputeResourcePolicyXSnapshotSchedulePolicyXScheduleXWeeklyScheduleXDayOfWeeks\"\xb8\x03\n5ComputeResourcePolicyXSnapshotSchedulePolicyXSchedule\x12}\n\x0e\x64\x61ily_schedule\x18\x01 \x01(\x0b\x32\x65.oak9.tython.gcp.compute_resource.ComputeResourcePolicyXSnapshotSchedulePolicyXScheduleXDailySchedule\x12\x7f\n\x0fhourly_schedule\x18\x02 \x01(\x0b\x32\x66.oak9.tython.gcp.compute_resource.ComputeResourcePolicyXSnapshotSchedulePolicyXScheduleXHourlySchedule\x12\x7f\n\x0fweekly_schedule\x18\x03 \x01(\x0b\x32\x66.oak9.tython.gcp.compute_resource.ComputeResourcePolicyXSnapshotSchedulePolicyXScheduleXWeeklySchedule\"\x9f\x02\n?ComputeResourcePolicyXSnapshotSchedulePolicyXSnapshotProperties\x12\x13\n\x0bguest_flush\x18\x01 \x01(\x08\x12}\n\x06labels\x18\x02 \x03(\x0b\x32m.oak9.tython.gcp.compute_resource.ComputeResourcePolicyXSnapshotSchedulePolicyXSnapshotProperties.LabelsEntry\x12\x19\n\x11storage_locations\x18\x03 \x03(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x93\x03\n,ComputeResourcePolicyXSnapshotSchedulePolicy\x12x\n\x10retention_policy\x18\x01 \x01(\x0b\x32^.oak9.tython.gcp.compute_resource.ComputeResourcePolicyXSnapshotSchedulePolicyXRetentionPolicy\x12i\n\x08schedule\x18\x02 \x01(\x0b\x32W.oak9.tython.gcp.compute_resource.ComputeResourcePolicyXSnapshotSchedulePolicyXSchedule\x12~\n\x13snapshot_properties\x18\x03 \x01(\x0b\x32\x61.oak9.tython.gcp.compute_resource.ComputeResourcePolicyXSnapshotSchedulePolicyXSnapshotProperties\"@\n\x1e\x43omputeResourcePolicyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xd9\x04\n\x15\x43omputeResourcePolicy\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0e\n\x06region\x18\x05 \x01(\t\x12\x11\n\tself_link\x18\x06 \x01(\t\x12l\n\x16group_placement_policy\x18\x07 \x01(\x0b\x32L.oak9.tython.gcp.compute_resource.ComputeResourcePolicyXGroupPlacementPolicy\x12p\n\x18instance_schedule_policy\x18\x08 \x01(\x0b\x32N.oak9.tython.gcp.compute_resource.ComputeResourcePolicyXInstanceSchedulePolicy\x12p\n\x18snapshot_schedule_policy\x18\t \x01(\x0b\x32N.oak9.tython.gcp.compute_resource.ComputeResourcePolicyXSnapshotSchedulePolicy\x12R\n\x08timeouts\x18\n \x01(\x0b\x32@.oak9.tython.gcp.compute_resource.ComputeResourcePolicyXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_resource_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTERESOURCEPOLICYXSNAPSHOTSCHEDULEPOLICYXSNAPSHOTPROPERTIES_LABELSENTRY._options = None
  _COMPUTERESOURCEPOLICYXSNAPSHOTSCHEDULEPOLICYXSNAPSHOTPROPERTIES_LABELSENTRY._serialized_options = b'8\001'
  _COMPUTERESOURCEPOLICYXGROUPPLACEMENTPOLICY._serialized_start=89
  _COMPUTERESOURCEPOLICYXGROUPPLACEMENTPOLICY._serialized_end=207
  _COMPUTERESOURCEPOLICYXINSTANCESCHEDULEPOLICYXVMSTARTSCHEDULE._serialized_start=209
  _COMPUTERESOURCEPOLICYXINSTANCESCHEDULEPOLICYXVMSTARTSCHEDULE._serialized_end=289
  _COMPUTERESOURCEPOLICYXINSTANCESCHEDULEPOLICYXVMSTOPSCHEDULE._serialized_start=291
  _COMPUTERESOURCEPOLICYXINSTANCESCHEDULEPOLICYXVMSTOPSCHEDULE._serialized_end=370
  _COMPUTERESOURCEPOLICYXINSTANCESCHEDULEPOLICY._serialized_start=373
  _COMPUTERESOURCEPOLICYXINSTANCESCHEDULEPOLICY._serialized_end=727
  _COMPUTERESOURCEPOLICYXSNAPSHOTSCHEDULEPOLICYXRETENTIONPOLICY._serialized_start=729
  _COMPUTERESOURCEPOLICYXSNAPSHOTSCHEDULEPOLICYXRETENTIONPOLICY._serialized_end=850
  _COMPUTERESOURCEPOLICYXSNAPSHOTSCHEDULEPOLICYXSCHEDULEXDAILYSCHEDULE._serialized_start=852
  _COMPUTERESOURCEPOLICYXSNAPSHOTSCHEDULEPOLICYXSCHEDULEXDAILYSCHEDULE._serialized_end=964
  _COMPUTERESOURCEPOLICYXSNAPSHOTSCHEDULEPOLICYXSCHEDULEXHOURLYSCHEDULE._serialized_start=966
  _COMPUTERESOURCEPOLICYXSNAPSHOTSCHEDULEPOLICYXSCHEDULEXHOURLYSCHEDULE._serialized_end=1080
  _COMPUTERESOURCEPOLICYXSNAPSHOTSCHEDULEPOLICYXSCHEDULEXWEEKLYSCHEDULEXDAYOFWEEKS._serialized_start=1082
  _COMPUTERESOURCEPOLICYXSNAPSHOTSCHEDULEPOLICYXSCHEDULEXWEEKLYSCHEDULEXDAYOFWEEKS._serialized_end=1196
  _COMPUTERESOURCEPOLICYXSNAPSHOTSCHEDULEPOLICYXSCHEDULEXWEEKLYSCHEDULE._serialized_start=1199
  _COMPUTERESOURCEPOLICYXSNAPSHOTSCHEDULEPOLICYXSCHEDULEXWEEKLYSCHEDULE._serialized_end=1407
  _COMPUTERESOURCEPOLICYXSNAPSHOTSCHEDULEPOLICYXSCHEDULE._serialized_start=1410
  _COMPUTERESOURCEPOLICYXSNAPSHOTSCHEDULEPOLICYXSCHEDULE._serialized_end=1850
  _COMPUTERESOURCEPOLICYXSNAPSHOTSCHEDULEPOLICYXSNAPSHOTPROPERTIES._serialized_start=1853
  _COMPUTERESOURCEPOLICYXSNAPSHOTSCHEDULEPOLICYXSNAPSHOTPROPERTIES._serialized_end=2140
  _COMPUTERESOURCEPOLICYXSNAPSHOTSCHEDULEPOLICYXSNAPSHOTPROPERTIES_LABELSENTRY._serialized_start=2095
  _COMPUTERESOURCEPOLICYXSNAPSHOTSCHEDULEPOLICYXSNAPSHOTPROPERTIES_LABELSENTRY._serialized_end=2140
  _COMPUTERESOURCEPOLICYXSNAPSHOTSCHEDULEPOLICY._serialized_start=2143
  _COMPUTERESOURCEPOLICYXSNAPSHOTSCHEDULEPOLICY._serialized_end=2546
  _COMPUTERESOURCEPOLICYXTIMEOUTS._serialized_start=2548
  _COMPUTERESOURCEPOLICYXTIMEOUTS._serialized_end=2612
  _COMPUTERESOURCEPOLICY._serialized_start=2615
  _COMPUTERESOURCEPOLICY._serialized_end=3216
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_appconfig.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61ws/aws_appconfig.proto\x12\x19oak9.tython.aws.appconfig\x1a\x13shared/shared.proto\"f\n\x0f\x41pplicationTags\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"\xa3\x01\n\x0b\x41pplication\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x38\n\x04tags\x18\x03 \x03(\x0b\x32*.oak9.tython.aws.appconfig.ApplicationTags\x12\x0c\n\x04name\x18\x04 \x01(\t\"\xb9\x03\n\tAppConfig\x12;\n\x0b\x61pplication\x18\x01 \x03(\x0b\x32&.oak9.tython.aws.appconfig.Application\x12N\n\x15\x63onfiguration_profile\x18\x02 \x03(\x0b\x32/.oak9.tython.aws.appconfig.ConfigurationProfile\x12\x39\n\ndeployment\x18\x03 \x03(\x0b\x32%.oak9.tython.aws.appconfig.Deployment\x12J\n\x13\x64\x65ployment_strategy\x18\x04 \x03(\x0b\x32-.oak9.tython.aws.appconfig.DeploymentStrategy\x12;\n\x0b\x65nvironment\x18\x05 \x03(\x0b\x32&.oak9.tython.aws.appconfig.Environment\x12[\n\x1chosted_configuration_version\x18\x06 \x03(\x0b\x32\x35.oak9.tython.aws.appconfig.HostedConfigurationVersion\"j\n\x1e\x43onfigurationProfileValidators\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\"o\n\x18\x43onfigurationProfileTags\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"\xce\x02\n\x14\x43onfigurationProfile\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0clocation_uri\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12M\n\nvalidators\x18\x04 \x03(\x0b\x32\x39.oak9.tython.aws.appconfig.ConfigurationProfileValidators\x12\x1a\n\x12retrieval_role_arn\x18\x05 \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\x06 \x01(\t\x12\x41\n\x04tags\x18\x07 \x03(\x0b\x32\x33.oak9.tython.aws.appconfig.ConfigurationProfileTags\x12\x0c\n\x04name\x18\x08 \x01(\t\"e\n\x0e\x44\x65ploymentTags\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"\xa4\x02\n\nDeployment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16\x64\x65ployment_strategy_id\x18\x02 \x01(\t\x12 \n\x18\x63onfiguration_profile_id\x18\x03 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x1d\n\x15\x63onfiguration_version\x18\x06 \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\x07 \x01(\t\x12\x37\n\x04tags\x18\x08 \x03(\x0b\x32).oak9.tython.aws.appconfig.DeploymentTags\"m\n\x16\x44\x65ploymentStrategyTags\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"\xbf\x02\n\x12\x44\x65ploymentStrategy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0creplicate_to\x18\x02 \x01(\t\x12\x13\n\x0bgrowth_type\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12&\n\x1e\x64\x65ployment_duration_in_minutes\x18\x05 \x01(\x01\x12\x15\n\rgrowth_factor\x18\x06 \x01(\x01\x12\"\n\x1a\x66inal_bake_time_in_minutes\x18\x07 \x01(\x01\x12?\n\x04tags\x18\x08 \x03(\x0b\x32\x31.oak9.tython.aws.appconfig.DeploymentStrategyTags\x12\x0c\n\x04name\x18\t \x01(\t\"y\n\x13\x45nvironmentMonitors\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\talarm_arn\x18\x02 \x01(\t\x12\x16\n\x0e\x61larm_role_arn\x18\x03 \x01(\t\"f\n\x0f\x45nvironmentTags\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"\xfd\x01\n\x0b\x45nvironment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12@\n\x08monitors\x18\x03 \x03(\x0b\x32..oak9.tython.aws.appconfig.EnvironmentMonitors\x12\x16\n\x0e\x61pplication_id\x18\x04 \x01(\t\x12\x38\n\x04tags\x18\x05 \x03(\x0b\x32*.oak9.tython.aws.appconfig.EnvironmentTags\x12\x0c\n\x04name\x18\x06 \x01(\t\"\xea\x01\n\x1aHostedConfigurationVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12 \n\x18\x63onfiguration_profile_id\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x14\n\x0c\x63ontent_type\x18\x04 \x01(\t\x12\x1d\n\x15latest_version_number\x18\x05 \x01(\x01\x12\x0f\n\x07\x63ontent\x18\x06 \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\x07 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_appconfig_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _APPLICATIONTAGS._serialized_start=75
  _APPLICATIONTAGS._serialized_end=177
  _APPLICATION._serialized_start=180
  _APPLICATION._serialized_end=343
  _APPCONFIG._serialized_start=346
  _APPCONFIG._serialized_end=787
  _CONFIGURATIONPROFILEVALIDATORS._serialized_start=789
  _CONFIGURATIONPROFILEVALIDATORS._serialized_end=895
  _CONFIGURATIONPROFILETAGS._serialized_start=897
  _CONFIGURATIONPROFILETAGS._serialized_end=1008
  _CONFIGURATIONPROFILE._serialized_start=1011
  _CONFIGURATIONPROFILE._serialized_end=1345
  _DEPLOYMENTTAGS._serialized_start=1347
  _DEPLOYMENTTAGS._serialized_end=1448
  _DEPLOYMENT._serialized_start=1451
  _DEPLOYMENT._serialized_end=1743
  _DEPLOYMENTSTRATEGYTAGS._serialized_start=1745
  _DEPLOYMENTSTRATEGYTAGS._serialized_end=1854
  _DEPLOYMENTSTRATEGY._serialized_start=1857
  _DEPLOYMENTSTRATEGY._serialized_end=2176
  _ENVIRONMENTMONITORS._serialized_start=2178
  _ENVIRONMENTMONITORS._serialized_end=2299
  _ENVIRONMENTTAGS._serialized_start=2301
  _ENVIRONMENTTAGS._serialized_end=2403
  _ENVIRONMENT._serialized_start=2406
  _ENVIRONMENT._serialized_end=2659
  _HOSTEDCONFIGURATIONVERSION._serialized_start=2662
  _HOSTEDCONFIGURATIONVERSION._serialized_end=2896
# @@protoc_insertion_point(module_scope)
